# Generated by roxygen2: do not edit by hand

S3method(get_contrast_registry,GseaEnv)
S3method(get_contrast_registry,GseaRes)
S3method(get_de_table,GseaRes)
S3method(get_expr_matrix,GseaEnv)
S3method(get_expr_matrix,GseaRes)
S3method(get_geneset_info,GseaEnv)
S3method(get_geneset_info,GseaRes)
S3method(get_sample_meta,GseaEnv)
S3method(get_sample_meta,GseaRes)
S3method(print,GseaBenchmarkAligned)
S3method(print,GseaEnv)
S3method(print,GseaRes)
export(batch_calc_gsea)
export(build_edge_list_safely)
export(build_gsea_pathways)
export(build_hubgene_network)
export(calculate_overlap_ratio)
export(color_by_direction)
export(creat_addition_data_rdsfile)
export(create_addition_template)
export(create_gsea_env)
export(create_gsea_res)
export(create_gsea_task)
export(extract_gsea_task)
export(extract_hub_genes)
export(generate_boxplot_data_code)
export(generate_boxplot_image_code)
export(generate_combined_plot_code)
export(generate_de_volcano_code)
export(generate_dotplot_code)
export(generate_gsea_html_report)
export(generate_hubgene_code)
export(generate_hubgene_hover_text)
export(generate_joint_canvas_code)
export(generate_network_code)
export(generate_pathway_plot_code)
export(generate_volcano_code)
export(get_contrast_registry)
export(get_core_genes_for_pathway)
export(get_core_genes_list)
export(get_de_table)
export(get_expr_matrix)
export(get_geneset_info)
export(get_hubgene_legend)
export(get_sample_meta)
export(get_term_genes)
export(import_gsea_capsule)
export(inspect_gsea_env)
export(inspect_gsea_res)
export(launch_gsea_app)
export(plot_directional_gsea)
export(plot_gsea_memory)
export(prepare_hubgene_nodes)
export(read_addition_data)
export(setup_gsea_env)
export(validate_param)
importFrom(ComplexHeatmap,Heatmap)
importFrom(ComplexHeatmap,HeatmapAnnotation)
importFrom(ComplexHeatmap,draw)
importFrom(ComplexHeatmap,rowAnnotation)
importFrom(DESeq2,DESeq)
importFrom(DESeq2,counts)
importFrom(DESeq2,estimateSizeFactors)
importFrom(DESeq2,results)
importFrom(DESeq2,resultsNames)
importFrom(DESeq2,vst)
importFrom(DT,dataTableOutput)
importFrom(DT,datatable)
importFrom(DT,formatStyle)
importFrom(DT,renderDataTable)
importFrom(DT,styleEqual)
importFrom(DT,styleInterval)
importFrom(S4Vectors,"metadata<-")
importFrom(S4Vectors,metadata)
importFrom(SummarizedExperiment,assay)
importFrom(SummarizedExperiment,colData)
importFrom(SummarizedExperiment,rowData)
importFrom(circlize,colorRamp2)
importFrom(clipr,write_clip)
importFrom(clusterProfiler,GSEA)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,coalesce)
importFrom(dplyr,desc)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,if_else)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,right_join)
importFrom(dplyr,select)
importFrom(dplyr,slice)
importFrom(dplyr,slice_head)
importFrom(dplyr,slice_tail)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(edgeR,DGEList)
importFrom(edgeR,calcNormFactors)
importFrom(edgeR,cpm)
importFrom(edgeR,rpkm)
importFrom(enrichit,gseaScores)
importFrom(enrichplot,cnetplot)
importFrom(enrichplot,dotplot)
importFrom(enrichplot,gseaplot)
importFrom(enrichplot,heatplot)
importFrom(enrichplot,ridgeplot)
importFrom(enrichplot,upsetplot)
importFrom(future,multisession)
importFrom(future,plan)
importFrom(future,sequential)
importFrom(future.apply,future_lapply)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,coord_cartesian)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_grid)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_jitter)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_rect)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,labs)
importFrom(ggplot2,margin)
importFrom(ggplot2,scale_alpha_manual)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_gradient2)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_size_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_minimal)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.off)
importFrom(grDevices,png)
importFrom(graphics,abline)
importFrom(graphics,barplot)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(grid,gpar)
importFrom(grid,grid.text)
importFrom(grid,unit)
importFrom(htmltools,HTML)
importFrom(htmltools,tags)
importFrom(htmlwidgets,JS)
importFrom(htmlwidgets,saveWidget)
importFrom(igraph,V)
importFrom(igraph,ecount)
importFrom(igraph,graph_from_data_frame)
importFrom(igraph,layout_in_circle)
importFrom(igraph,layout_with_fr)
importFrom(igraph,layout_with_kk)
importFrom(igraph,vcount)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(limma,contrasts.fit)
importFrom(limma,eBayes)
importFrom(limma,makeContrasts)
importFrom(limma,topTable)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,slot)
importFrom(methods,slotNames)
importFrom(msigdbr,msigdbr)
importFrom(msigdbr,msigdbr_collections)
importFrom(patchwork,plot_annotation)
importFrom(patchwork,wrap_plots)
importFrom(plotly,add_annotations)
importFrom(plotly,event_data)
importFrom(plotly,ggplotly)
importFrom(plotly,layout)
importFrom(plotly,plot_ly)
importFrom(plotly,plotlyOutput)
importFrom(plotly,renderPlotly)
importFrom(plotly,style)
importFrom(progressr,handlers)
importFrom(progressr,progressor)
importFrom(rlang,.data)
importFrom(rlang,`%||%`)
importFrom(shiny,HTML)
importFrom(shiny,NS)
importFrom(shiny,actionButton)
importFrom(shiny,br)
importFrom(shiny,div)
importFrom(shiny,fluidPage)
importFrom(shiny,h4)
importFrom(shiny,hr)
importFrom(shiny,icon)
importFrom(shiny,invalidateLater)
importFrom(shiny,isolate)
importFrom(shiny,mainPanel)
importFrom(shiny,modalDialog)
importFrom(shiny,moduleServer)
importFrom(shiny,need)
importFrom(shiny,observeEvent)
importFrom(shiny,reactive)
importFrom(shiny,reactiveVal)
importFrom(shiny,renderPlot)
importFrom(shiny,renderText)
importFrom(shiny,req)
importFrom(shiny,selectInput)
importFrom(shiny,shinyApp)
importFrom(shiny,showModal)
importFrom(shiny,showNotification)
importFrom(shiny,sidebarLayout)
importFrom(shiny,sidebarPanel)
importFrom(shiny,span)
importFrom(shiny,tabPanel)
importFrom(shiny,tabsetPanel)
importFrom(shiny,tagList)
importFrom(shiny,tags)
importFrom(shiny,textInput)
importFrom(shiny,titlePanel)
importFrom(shiny,updateSelectInput)
importFrom(shiny,updateSelectizeInput)
importFrom(shiny,validate)
importFrom(shinycssloaders,withSpinner)
importFrom(shinyjs,disable)
importFrom(shinyjs,enable)
importFrom(stats,aggregate)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,quantile)
importFrom(stats,reorder)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,var)
importFrom(stringr,str_c)
importFrom(stringr,str_detect)
importFrom(stringr,str_replace)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_split)
importFrom(stringr,str_sub)
importFrom(stringr,str_to_title)
importFrom(stringr,str_trim)
importFrom(stringr,str_wrap)
importFrom(tibble,as_tibble)
importFrom(tibble,deframe)
importFrom(tibble,enframe)
importFrom(tibble,rownames_to_column)
importFrom(tibble,tibble)
importFrom(tidyr,drop_na)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidyr,separate)
importFrom(tidyr,unite)
importFrom(tools,file_ext)
importFrom(utils,combn)
importFrom(utils,data)
importFrom(utils,head)
importFrom(utils,packageVersion)
importFrom(utils,read.csv)
importFrom(utils,tail)
importFrom(visNetwork,renderVisNetwork)
importFrom(visNetwork,visEvents)
importFrom(visNetwork,visInteraction)
importFrom(visNetwork,visLayout)
importFrom(visNetwork,visNetwork)
importFrom(visNetwork,visNetworkOutput)
importFrom(visNetwork,visOptions)
importFrom(visNetwork,visPhysics)
importFrom(withr,local_seed)
importFrom(withr,with_seed)
