% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{preprocessed_dds}
\alias{preprocessed_dds}
\title{Pre-computed DESeq2 DESeqDataSet from the airway dataset}
\format{
A `DESeqDataSet` object.
}
\source{
Built from the `airway` Bioconductor dataset via DESeq2.
}
\description{
A slimmed `DESeqDataSet` object fitted with `DESeq()`,
  suitable as input to [GSEAlens::setup_gsea_env()].
}
\examples{
data(preprocessed_dds, package = "GSEAlens")
class(preprocessed_dds)
}
