% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/11_shiny_mod_modal.R
\name{mod_pathway_modal_ui}
\alias{mod_pathway_modal_ui}
\title{Pathway Detail Modal UI}
\usage{
mod_pathway_modal_ui(id)
}
\description{
Pathway Detail Modal UI
}
\keyword{internal}
