% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/01_backends.R
\name{backends}
\alias{backends}
\title{Backend Data Extractor}
\description{
Extract standardized data structures from limma or DESeq2 objects.
}
\keyword{internal}
