% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-imports.R
\name{utils-imports}
\alias{utils-imports}
\title{GSEAlens Global Imports}
\description{
Centralized management of all external dependency imports to avoid redundant definitions
}
\keyword{internal}
